@@ -4,4 +4,4 @@ import SWHelpers
 from ImageContour import SubContourTools
 from _version import *
 
-__all__ = ['SeedWaterSegmenter','SWHelpers']
+__all__ = ["SeedWaterSegmenter", "SWHelpers"]
